@@ -1,10 +1,10 @@
 use crate::{bounds_for, boxed::BoxedString, inline::InlineString, SmartString, SmartStringMode};
-use std::{
+use alloc::string::Drain as StringDrain;
+use core::{
     fmt::{Debug, Error, Formatter},
     iter::FusedIterator,
     ops::RangeBounds,
     str::Chars,
-    string::Drain as StringDrain,
 };
 
 /// A draining iterator for a [`SmartString`][SmartString].
